@@ -30,3 +30,17 @@ pub fn inner_ty(orig_fn_ret_ty: syn::Type) -> Option<syn::GenericArgument> {
  };
  args.map(|args| args.into_iter().next()).flatten()
 }
+
+#[cfg(test)]
+mod tests {
+ use super::*;
+
+ #[test]
+ fn test_extract_result() {
+  assert_eq!(
+   inner_ty(syn::parse_str::<syn::Type>("Result<String, JsValue>").unwrap()),
+   Some(syn::parse_str::<syn::GenericArgument>("String").unwrap())
+  );
+  assert_eq!(inner_ty(syn::parse_str::<syn::Type>("String").unwrap()), None);
+ }
+}
